==> webkitgtk_2.4.11.orig.tar.xz: webkitgtk-2.4.11/Source/JavaScriptCore/heap/WriteBarrierBuffer.h <==
/*
 * Copyright (C) 2013 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#ifndef WriteBarrierBuffer_h
#define WriteBarrierBuffer_h

#include <wtf/FastMalloc.h>

namespace JSC {

class Heap;
class JSCell;

namespace FTL { class LowerDFGToLLVM; }

class WriteBarrierBuffer {
    friend class FTL::LowerDFGToLLVM;
public:
    WriteBarrierBuffer(unsigned capacity);
    ~WriteBarrierBuffer();

    void add(JSCell*);
    void flush(Heap&);
    void reset();

    static ptrdiff_t currentIndexOffset()
    {
        return OBJECT_OFFSETOF(WriteBarrierBuffer, m_currentIndex);
    }

    static ptrdiff_t capacityOffset()
    {
        return OBJECT_OFFSETOF(WriteBarrierBuffer, m_capacity);
    }

    static ptrdiff_t bufferOffset()
    {
        return OBJECT_OFFSETOF(WriteBarrierBuffer, m_buffer);
    }

private:
    unsigned m_currentIndex;
    unsigned m_capacity;
    JSCell** m_buffer;
};

} // namespace JSC

#endif // WriteBarrierBuffer_h

==> webkitgtk-2.15.1.tar.xz: webkitgtk-2.15.1/Source/JavaScriptCore/heap/WriteBarrierBuffer.h <==
/*
 * Copyright (C) 2013, 2015 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#pragma once

#include <wtf/FastMalloc.h>

namespace JSC {

class Heap;
class JSCell;

class WriteBarrierBuffer {
public:
    WriteBarrierBuffer(unsigned capacity);
    ~WriteBarrierBuffer();

    void add(JSCell*);
    void flush(Heap&);
    void reset();

    unsigned* currentIndexAddress()
    {
        return &m_currentIndex;
    }

    unsigned capacity() const
    {
        return m_capacity;
    }

    JSCell** buffer()
    {
        return m_buffer;
    }

private:
    unsigned m_currentIndex;
    const unsigned m_capacity;
    JSCell** const m_buffer;
};

} // namespace JSC
